##  Testing a Processor
To verify the processor configuration, you can complete a test run. This doesn't apply any changes to your workspace.
To complete a test run, click Test Run at the bottom of the processor page. The results of the test run appear in the Output Log section. Review the output for possible errors and update the processor configuration or input as needed.
![Output Log](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743adc17a441014be9afd2d2c2f6e60_LowRes.png)
Testing a Processor and Previewing Results in the Output Log
